/*
 * Blog name and description
 */

.andablog-header {
  padding-top: 20px;
  padding-bottom: 20px;
}
.andablog-title {
  margin-top: 30px;
  margin-bottom: 0;
  font-size: 60px;
  font-weight: normal;
}
.andablog-description {
  font-size: 20px;
  color: #999;
}


/*
 * Main column and sidebar layout
 */

.andablog-main {
  font-size: 18px;
  line-height: 1.5;
}

/* Sidebar modules for boxing content */
.sidebar-module {
  padding: 15px;
  margin: 0 -15px 15px;
}
.sidebar-module-inset {
  padding: 15px;
  background-color: #f5f5f5;
  border-radius: 4px;
}
.sidebar-module-inset p:last-child,
.sidebar-module-inset ul:last-child,
.sidebar-module-inset ol:last-child {
  margin-bottom: 0;
}



/* Pagination */
.pager {
  margin-bottom: 60px;
  text-align: left;
}
.pager > li > a {
  width: 140px;
  padding: 10px 20px;
  text-align: center;
  border-radius: 30px;
}


/*
 * Blog posts
 */

.andablog-post {
  margin-bottom: 60px;
}
.andablog-post-title {
  margin-bottom: 5px;
  font-size: 40px;
}
.andablog-post-meta {
  margin-bottom: 20px;
  color: #999;
}
