{% load trans from i18n %}

<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE }}">
    <head>
        <title>{% block title %}{% block subtitle %}{% endblock %} - Untitled{% endblock %}</title>
        <meta http-equiv="content-type" content="text/html; charset=UTF-8">
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        {% block head_meta %}
        {% endblock %}

        {% block head_styles %}
        {% endblock %}

        {% block head_scripts %}
        {% endblock %}
    </head>

    <body>
        {% if messages %}
            <div>
                <strong>Messages:</strong>
                <ul>
                {% for message in messages %}
                    <li>{{message}}</li>
                {% endfor %}
                </ul>
            </div>
        {% endif %}

        <div>
            {% block content %}{% endblock %}
        </div>

        {% block body_scripts %}{% endblock %}
    </body>
</html>
