{% load andablog_tags %}

<ul class="media-list">
    {% for comment in comment_list %}
        <li id="c{{ comment.id }}" class="media">
            <div class="media-body">
                <h4 class="media-heading">{{ comment.user|authordisplay }} - {{ comment.submit_date|date:"SHORT_DATETIME_FORMAT" }} (<a href="#c{{ comment.id }}">direct link</a>)</h4>

                <p>{{ comment.comment }}</p>
            </div>
        </li>
    {% endfor %}
</ul>
