{% extends "base.html" %}
{% load staticfiles %}

{% block subtitle %}
    {% block andablog_page_title %}
    {% endblock %}
{% endblock %}

{% block head_styles %}
    {% block andablog_head_extra %}
        <link rel="stylesheet" href="{% static 'css/andablog.css' %}">
    {% endblock %}
{% endblock %}

{% block menu-blog-class %}active{% endblock %}

{% block content %}
    {% block andablog_content %}
    {% endblock %}
{% endblock %}
